/*
 * PowerTracer
 * http://eeclust.de
 *
 * Copyright (c) 2010-2012, University of Hamburg
 *
 * See the file COPYING in the package base directory for details
 *
 * LMGSet.c
 *
 *  Created on: May 11, 2011
 *  Author: Timo Minartz
 */

#include "LMGSet.h"

LMGSet* LMGSet_alloc(void) {
	LMGSet* set = g_malloc(sizeof(LMGSet));
	set->size = 0;
	set->list = NULL;

	return set;
}

void LMGSet_unref(LMGSet* set) {
	if (set != NULL) {
		GList * it = g_list_first(set->list);

		while (it != NULL) {
			LMG * lmg = (LMG*) it->data;
			LMG_unref(lmg);
			it = it->next;
		}

		g_list_free(set->list);

		g_free(set);

	}
}

Cycle** LMGSet_alloc_cycles(LMGSet* set) {

	if (set == NULL)
		return NULL;

	Cycle ** cycles = g_malloc(set->size * sizeof(Cycle*));

	if (cycles == NULL)
		return NULL;

	GList * it = g_list_first(set->list);

	int i = 0;
	while (it != NULL) {
		LMG * lmg = (LMG*) it->data;
		if (lmg != NULL)
			cycles[i++] = LMG_alloc_cycle(lmg);
		it = it->next;
	}

	return cycles;
}

void LMGSet_unref_cycles(const LMGSet* set, Cycle ** cycles) {

	if (set != NULL && cycles != NULL) {
		GList * it = g_list_first(set->list);

		int i = 0;
		while (it != NULL) {
			LMG * lmg = (LMG*) it->data;
			if (lmg != NULL)
				LMG_unref_cycle(lmg, cycles[i++]);
			it = it->next;
		}

		g_free(cycles);
		cycles = NULL;
	}
}

void LMGSet_add(LMGSet * set, const LMG * lmg) {
	if (set != NULL) {
		set->list = g_list_append(set->list, (gpointer) lmg);
		set->size = set->size + 1;
	}
}

void LMGSet_send_command(const LMGSet * set, const gchar* command) {

	if (set != NULL && command != NULL) {
		GList * it = g_list_first(set->list);

		while (it != NULL) {
			LMG * lmg = (LMG*) it->data;

			if (lmg != NULL)
				LMG_send_command(lmg, command);
			it = it->next;
		}
	}
}

void LMGSet_read_cycles(const LMGSet * set, Cycle ** cycles) {

	if (set != NULL && cycles != NULL) {
		GList * it = g_list_first(set->list);

		int i = 0;
		while (it != NULL) {
			LMG * lmg = (LMG*) it->data;
			if (lmg != NULL && cycles[i] != NULL)
				LMG_read_cycle(lmg, cycles[i++]);
			it = it->next;
		}
	}
}

gint LMGSet_get_size(const LMGSet * set) {
	return set->size;
}
