/*
 * PowerTracer
 * http://eeclust.de
 *
 * Copyright (c) 2010-2012, University of Hamburg
 *
 * See the file COPYING in the package base directory for details
 *
 * LMGSet.h
 *
 *  Created on: May 11, 2011
 *  Author: Timo Minartz
 */

#ifndef LMGSET_H_
#define LMGSET_H_

#include <glib.h>
#include "LMG.h"

typedef struct {
	GList* list;
	gint size;
} LMGSet;

/**
 * Allocates a new set for LMG devices. Multiple LMG devices can be grouped and handeled as one device.
 * @return Newly allocated pointer to LMGSet, has be freed using LMGSet_unref()
 */
LMGSet* LMGSet_alloc(void);

/**
 * Allocates a measurement cycle element for this LMG set. Calls LMG_alloc_cycle for each LMG device inside this set.
 * @param set LMG set to construct Cycles for
 * @return Newly allocated array of pointers to Cycles, has be freed using LMGSet_unref_cycle()
 */
Cycle** LMGSet_alloc_cycles(LMGSet* set);

/**
 * Frees all LMG devices in this set calling LMG_unref() and the device itself
 * @param set LMGSet to free
 */
void LMGSet_unref(LMGSet* set);

/**
 * Frees all Cycles and the array itself
 * @param set LMGSet cycles belongs to
 * @param cycles Cycles to free
 */
void LMGSet_unref_cycles(const LMGSet* set, Cycle ** cycles);

/**
 * Adds an already existing LMG device to the set
 * @param set LMGSet for adding lmg
 * @aram lmg LMG to add
 */
void LMGSet_add(LMGSet * set, const LMG * lmg);

/**
 * Sends a command to all devices in the set calling LMG_send_command()
 * @param set LMGSet for executing command
 * @param command Command to be executed on all devices, must end with newline
 */
void LMGSet_send_command(const LMGSet * set, const gchar* command);

/**
 * Reads one measurement cycle from all devices in the set.
 * @param set LMGSet to read cycles from
 * @param cycles Array to already allocated pointer to Cycle objects which will contain the measurement cycle data after the call
 */
void LMGSet_read_cycles(const LMGSet * set, Cycle** cycles);

/**
 * Returns the size of the set
 * @return Size of set
 */
gint LMGSet_get_size(const LMGSet * set);


#endif /* LMGSET_H_ */
