/*
 * PowerTracer
 * http://eeclust.de
 *
 * Copyright (c) 2010-2012, University of Hamburg
 *
 * See the file COPYING in the package base directory for details
 *
 * resetLMG.c
 *
 *  Created on: May 11, 2011
 *  Author: Timo Minartz
 */

#include <stdlib.h> // for atoi
#include <string.h> // for strlen
#include <unistd.h> // for sleep

#include "LMG.h"

gboolean debug = FALSE;
gboolean verbose = TRUE;

static const gchar* names[3][4] = { { "amd2", "amd3", "amd4", "amd5" }, {
			"switch", "nas1", "intel1", "intel2" }, { "intel3", "intel4",
			"intel5", "amd1" } };

gint main(gint argc, gchar **argv) {

	gchar ports[3][13] = { "/dev/ttyUSB0", "/dev/ttyUSB1", "/dev/ttyUSB2" };

	gint from = 0, to = 3;

	if (argc > 1) {
		if (strlen(argv[1]) == 1) {
			from = atoi(argv[1]);
			to = from + 1;
		} else {
			g_print("Unknown arg: %s, must be one of 0,1 or 2\n", argv[1]);
			return 1;
		}
	}

	for (gint i = from; i < to; ++i) {

		gchar *port = ports[i];

		g_print("Opening device on port: %s\n", port);

		LMG * lmg = LMG_alloc(port, 4, names[i]);

		g_print("Fetching errors from device...\n");

		gchar * errors = LMG_get_all_errors(lmg);

		g_print("Errors: %s\n", errors);

		g_free(errors);

		g_print("Reset device...\n");

		LMG_reset(lmg);

		g_print("Fetching identity...\n");

		gchar * identity = LMG_get_identity(lmg);

		g_print("Identity: %s\n", identity);

		g_free(identity);

		g_print("Setting default ranges...\n");

		LMG_set_default_ranges(lmg);

		g_print("Getting ranges from device...\n");

		LMG_print_ranges(lmg);

		g_print("Fetching errors from device...\n");

		errors = LMG_get_all_errors(lmg);

		g_print("Errors: %s\n", errors);

		g_free(errors);

		LMG_beep(lmg);

		LMG_unref(lmg);
	}

	return 0;
}
